==> xfce4-terminal_0.2.10.orig.tar.gz: Terminal-0.2.10/terminal/terminal-preferences-dialog.h <==
/* $Id$ */
/*-
 * Copyright (c) 2004-2007 os-cillation e.K.
 *
 * Written by Benedikt Meurer <benny@xfce.org>.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __TERMINAL_PREFERENCES_DIALOG_H__
#define __TERMINAL_PREFERENCES_DIALOG_H__

#include <exo/exo.h>

#include <terminal/terminal-preferences.h>

G_BEGIN_DECLS;

#define TERMINAL_TYPE_PREFERENCES_DIALOG            (terminal_preferences_dialog_get_type ())
#define TERMINAL_PREFERENCES_DIALOG(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), TERMINAL_TYPE_PREFERENCES_DIALOG, TerminalPreferencesDialog))
#define TERMINAL_PREFERENCES_DIALOG_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), TERMINAL_TYPE_PREFERENCES_DIALOG, TerminalPreferencesDialogClass))
#define TERMINAL_IS_PREFERENCES_DIALOG(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TERMINAL_TYPE_PREFERENCES_DIALOG))
#define TERMINAL_IS_PREFERENCES_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((obj), TERMINAL_TYPE_PREFERENCES_DIALOG))
#define TERMINAL_PREFERENCES_DIALOG_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), TERMINAL_TYPE_PREFERENCES_DIALOG, TerminalPreferencesDialogClass))

typedef struct _TerminalPreferencesDialogClass TerminalPreferencesDialogClass;
typedef struct _TerminalPreferencesDialog      TerminalPreferencesDialog;

struct _TerminalPreferencesDialogClass
{
  GtkDialogClass  __parent__;
};

struct _TerminalPreferencesDialog
{
  GtkDialog            __parent__;

  TerminalPreferences *preferences;

  GtkWidget           *icon_bar;
  GtkWidget           *notebook;
};

GType      terminal_preferences_dialog_get_type (void) G_GNUC_CONST;

GtkWidget *terminal_preferences_dialog_new      (GtkWindow *parent);

G_END_DECLS;

#endif /* !__TERMINAL_PREFERENCES_DIALOG_H__ */

==> xfce4-terminal_0.4.3.orig.tar.gz: Terminal-0.4.3/terminal/terminal-preferences-dialog.h <==
/* $Id$ */
/*-
 * Copyright (c) 2004-2007 os-cillation e.K.
 *
 * Written by Benedikt Meurer <benny@xfce.org>.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __TERMINAL_PREFERENCES_DIALOG_H__
#define __TERMINAL_PREFERENCES_DIALOG_H__

#include <exo/exo.h>

#include <terminal/terminal-preferences.h>

G_BEGIN_DECLS

#define TERMINAL_TYPE_PREFERENCES_DIALOG            (terminal_preferences_dialog_get_type ())
#define TERMINAL_PREFERENCES_DIALOG(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), TERMINAL_TYPE_PREFERENCES_DIALOG, TerminalPreferencesDialog))
#define TERMINAL_PREFERENCES_DIALOG_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), TERMINAL_TYPE_PREFERENCES_DIALOG, TerminalPreferencesDialogClass))
#define TERMINAL_IS_PREFERENCES_DIALOG(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TERMINAL_TYPE_PREFERENCES_DIALOG))
#define TERMINAL_IS_PREFERENCES_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((obj), TERMINAL_TYPE_PREFERENCES_DIALOG))
#define TERMINAL_PREFERENCES_DIALOG_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), TERMINAL_TYPE_PREFERENCES_DIALOG, TerminalPreferencesDialogClass))

typedef struct _TerminalPreferencesDialogClass TerminalPreferencesDialogClass;
typedef struct _TerminalPreferencesDialog      TerminalPreferencesDialog;

struct _TerminalPreferencesDialogClass
{
  GtkBuilderClass __parent__;
};

struct _TerminalPreferencesDialog
{
  GtkBuilder           __parent__;

  TerminalPreferences *preferences;
  guint                signal_id;
};

GType      terminal_preferences_dialog_get_type (void) G_GNUC_CONST;

GtkWidget *terminal_preferences_dialog_new      (GtkWindow *parent);

G_END_DECLS

#endif /* !__TERMINAL_PREFERENCES_DIALOG_H__ */
